@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.h 2467 2007-06-30 02:57:59Z svn $
+ * $Id: DownloadFlowController.h 2576 2007-10-13 19:18:17Z svn $
  *****************************************************************************/
 
 #ifndef DOWNLOAD_FLOW_CONTROLLER_H
@@ -83,10 +83,13 @@ public:
     DownloadSession(DownloadFlowController *flow_controller,
                     apr_sockaddr_t *sockaddr)
       : flow_controller_(flow_controller),
-        sockaddr_(sockaddr),
-        is_valid_(false)
+        sockaddr_(sockaddr)
     {
+        is_valid_ = flow_controller_->add_session(sockaddr_);
 
+        if (!is_valid_) {
+            apr_sleep(apr_time_from_sec(DOWNLOAD_BUSY_SLEEP_SEC));
+        }
     };
     ~DownloadSession()
     {
@@ -94,7 +97,10 @@ public:
             flow_controller_->remove_session(sockaddr_);
         }
     };
-    bool is_valid();
+    bool is_valid()
+    {
+        return is_valid_;
+    };
 
 private:
     static const apr_size_t DOWNLOAD_BUSY_SLEEP_SEC;
