@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: FileWriter.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: FileWriter.h 2595 2007-10-22 14:36:13Z svn $
  *****************************************************************************/
 
 #ifndef FILE_WRITER_H
@@ -35,6 +35,8 @@
 #include "apr_file_io.h"
 
 #include "Uncopyable.h"
+#include "Message.h"
+#include "Macro.h"
 
 
 class File;
@@ -66,9 +68,11 @@ public:
             return;
         }
 
-        write_impl(buffer, size);
+        if (write_impl(buffer, size) != size) {
+            THROW(MESSAGE_FILE_WRITE_FAILED);
+        }
         write_size_ += size;
-    }
+    };
     /**
      * ファイルへの書き出しを行います．
      * 実際の書き込み処理は write_impl に委譲します．
@@ -86,7 +90,7 @@ public:
      *
      * @exception const char * 閉じるのに失敗した場合
      */
-    apr_size_t get_write_size() const
+    apr_uint64_t get_write_size() const
     {
         return write_size_;
     };
@@ -104,16 +108,17 @@ protected:
      *
      * @param[in] buffer 書き出すデータ
      * @param[in] size 書き出すサイズ
+     * @return 実際に書き出したサイズ
      * @exception const char * 書き出しに失敗した場合
      */
-    virtual void write_impl(const void *buffer, apr_size_t size) = 0;
+    virtual apr_size_t write_impl(const void *buffer, apr_size_t size) = 0;
 
     /** プール */
     apr_pool_t *pool_;
     /** ファイルハンドラ */
     File *file_;
     /** 書き込んだサイズ */
-    apr_size_t write_size_;
+    apr_uint64_t write_size_;
 };
 
 #endif
