@@ -22,17 +22,17 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Message.h 2399 2007-04-28 13:08:18Z svn $
+ * $Id: Message.h 2604 2007-10-26 13:58:10Z svn $
  *****************************************************************************/
 
 #ifndef MESSAGE_H
 #define MESSAGE_H
 
-#ifdef LOCALE_JA
-#include "MessageJA.h"
-#else
+// #ifdef LOCALE_JA
+// #include "MessageJA.h"
+// #else
 #include "MessageEN.h"
-#endif
+// #endif
 
 #endif
 
