@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: MmapFileWriter.h 2595 2007-10-22 14:36:13Z svn $
  *****************************************************************************/
 
 #ifndef MMAP_FILE_WRITER_H
@@ -73,9 +73,10 @@ private:
      *
      * @param[in] buffer 書き出すデータ
      * @param[in] size 書き出すサイズ
+     * @return 実際に書き出したサイズ
      * @exception const char * 書き出しに失敗した場合
      */
-    void write_impl(const void *buffer, apr_size_t size);
+    apr_size_t write_impl(const void *buffer, apr_size_t size);
     /**
      * OS のページサイズ
      *
