@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RFC1867Parser.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: RFC1867Parser.h 2588 2007-10-20 10:51:51Z svn $
  *****************************************************************************/
 
 #ifndef RFC1867_PARSER_H
@@ -75,7 +75,7 @@ public:
      * @param[in] content_size Content-Length
      */
     apr_array_header_t *parse(const char *content_type,
-                              apr_size_t content_size);
+                              apr_uint64_t content_size);
 
 private:
     typedef R PostReaderClass;
