@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ResponseWriter.h 2296 2006-12-24 02:58:57Z svn $
+ * $Id: ResponseWriter.h 2540 2007-07-21 15:21:47Z svn $
  *****************************************************************************/
 
 #ifndef RESPONSE_WRITER_H
@@ -45,7 +45,9 @@ public:
     void write(const char *str, apr_size_t length);
     void write(const char *str);
     void write(int i);
-private:
+
+protected:
+    apr_pool_t *pool_;
 };
 
 #endif
