@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 2563 2007-08-28 04:12:55Z svn $
+ * $Id: UploadItem.h 2604 2007-10-26 13:58:10Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_H
@@ -171,6 +171,7 @@ public:
      * @paramp[in] remove_pass 削除パスワード
      * @paramp[in] download_pass ダウンロードパスワード
      * @paramp[in] comment コメント
+     * @paramp[in] code_pat 「京」の 1 バイト目の値
      * @paramp[in] is_need_validate 内容をチェックするかどうか
      * @return インスタンス
      */
@@ -184,6 +185,7 @@ public:
                                     const char *remove_pass,
                                     const char *download_pass,
                                     const char *comment,
+                                    const char *code_pat,
                                     bool is_need_validate=true);
 
     /**
@@ -215,6 +217,7 @@ public:
                                     const char *remove_pass="",
                                     const char *download_pass="",
                                     const char *comment="",
+                                    const char *code_pat="",
                                     bool is_need_validate=true);
     static int cmp_download_count(const UploadItem *a, const UploadItem *b);
 
