@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 2466 2007-06-30 02:48:14Z svn $
+ * $Id: UploadItemList.h 2567 2007-10-10 17:12:24Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_HEADER_LIST_H
@@ -41,12 +41,11 @@
 
 /**
  * @brief アップロードアイテムのリストを表すクラス．
+ * このクラスでは排他処理を行いません．
  */
 class UploadItemList: public Uncopyable
 {
 public:
-    UploadItemList(apr_shm_t *shm, apr_uint64_t max_file_size,
-                   apr_size_t max_list_size);
     /**
      * アイテムをリストに追加します．
      *
@@ -65,9 +64,13 @@ public:
      * @param[in] item_id アイテム ID
      * @return アイテムヘッダ
      */
-    UploadItem::header_t *get_by_id(apr_size_t item_id) const
+    const UploadItem::header_t *get_by_id(apr_size_t item_id) const
     {
-        return (header_list_ + get_index_by_id(item_id));
+        return get_by_index(get_index_by_id(item_id));
+    };
+    UploadItem::header_t *get_by_id(apr_size_t item_id)
+    {
+        return get_by_index(get_index_by_id(item_id));
     };
     /**
      * 指定されたインデックスのアイテムを返します．
@@ -75,9 +78,13 @@ public:
      * @param[in] i インデックス
      * @return アイテムヘッダ
      */
-    UploadItem::header_t *get_by_index(apr_size_t i) const
+    const UploadItem::header_t *get_by_index(apr_size_t i) const
     {
-        return header_list_ + i;
+        return get_header_list() + i;
+    };
+    UploadItem::header_t *get_by_index(apr_size_t i)
+    {
+        return get_header_list() + i;
     };
     apr_size_t size() const
     {
@@ -121,29 +128,25 @@ public:
                                  UploadItemList *list);
 
 private:
-    /**
-     * 子プロセス用の初期化を行います．
-     */
-    void child_init_impl();
-    /**
-     * 共有メモリを初期化します．
-     */
-    void init_shm();
-    /**
-     * 共有メモリを子プロセス用に初期化します．
-     *
-     * @param[in] pool プール
-     */
-    void attach_shm();
+    UploadItemList(apr_shm_t *shm, apr_uint64_t max_file_size,
+                   apr_size_t max_list_size);
+    const UploadItem::header_t *get_header_list() const
+    {
+        return reinterpret_cast<const UploadItem::header_t *>(this + 1);
+    };
+    UploadItem::header_t *get_header_list()
+    {
+        return reinterpret_cast<UploadItem::header_t *>(this + 1);
+    };
     apr_size_t get_insert_index(UploadItem *uitem) const;
     apr_size_t get_index_by_id(apr_size_t item_id) const;
 
     static void load_header(UploadItem *uitem, UploadItem::header_t *header);
 
-    static void dump_header(apr_pool_t *pool, UploadItem::header_t *header);
+    static void dump_header(apr_pool_t *pool,
+                            const UploadItem::header_t *header);
     static void dump_date(apr_pool_t *pool, apr_time_t time);
 
-    UploadItem::header_t *header_list_;
     apr_size_t header_list_size_;
     apr_uint64_t total_file_size_;
     apr_uint64_t max_file_size_;
