@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.h 2568 2007-10-11 15:47:19Z svn $
+ * $Id: UploadItemManager.h 2604 2007-10-26 13:58:10Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_MANAGER_H
@@ -58,7 +58,7 @@ public:
                    apr_uint64_t file_size, const char *file_digest,
                    const char *file_temp_path, const char *remove_pass,
                    const char *download_pass, const char *comment,
-                   const char *ip_address);
+                   const char *code_pat, const char *ip_address);
     void remove(apr_pool_t *pool, UploadItem *uitem);
     UploadItem *get_item(apr_pool_t *pool, apr_size_t item_id);
     apr_file_t *get_item_file(apr_pool_t *pool, apr_size_t item_id,
@@ -133,7 +133,7 @@ private:
                         apr_uint64_t file_size, const char *file_digest,
                         const char *file_temp_path, const char *remove_pass,
                         const char *download_pass, const char *comment,
-                        const char *ip_address);
+                        const char *code_pat, const char *ip_address);
     void remove_impl(apr_pool_t *pool, UploadItem *uitem);
 
     /**
