@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.h 2388 2007-03-10 11:34:50Z svn $
+ * $Id: UploaderConfig.h 2591 2007-10-21 14:52:01Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_CONFIG_H
@@ -60,11 +60,13 @@ public:
     } item_t;
     enum template_type_t {
         INDEX_VIEW,
+        INFO_VIEW,
         PROGRESS_VIEW,
         DOWNLOAD_VIEW,
         THUMBNAIL_VIEW,
         ADMIN_VIEW,
         ERROR_VIEW,
+        __TMPL_COUNT__
     };
 
     static const item_t BASE_URL;
@@ -79,6 +81,7 @@ public:
     static const item_t PER_PAGE_ITEM_NUMBER;
 
     static const item_t INDEX_VIEW_TEMPLATE;
+    static const item_t INFO_VIEW_TEMPLATE;
     static const item_t PROGRESS_VIEW_TEMPLATE;
     static const item_t DOWNLOAD_VIEW_TEMPLATE;
     static const item_t THUMBNAIL_VIEW_TEMPLATE;
@@ -151,7 +154,7 @@ private:
     void check_template();
     void load_template();
     void update_template(template_type_t type);
-    const char *self_to_string(apr_pool_t *pool);
+    const char *config_to_string(apr_pool_t *pool);
 
     apr_pool_t *pool_;
 
@@ -171,7 +174,7 @@ private:
     PostFlowController *post_flow_controller_;
     PostProgressList *post_progress_list_;
 
-    UploaderTemplate *tmpls_[6];
+    UploaderTemplate *tmpls_[__TMPL_COUNT__];
 };
 
 #endif
