@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_util.h 2506 2007-07-06 18:21:58Z svn $
+ * $Id: uploader_util.h 2604 2007-10-26 13:58:10Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_UTIL_H
@@ -43,6 +43,7 @@ static const char POST_FILE_PARAM[]                 = "file";
 static const char POST_COMMENT_PARAM[]              = "comment";
 static const char POST_REMOVE_PASS_PARAM[]          = "remove_pass";
 static const char POST_DOWNLOAD_PASS_PARAM[]        = "download_pass";
+static const char POST_CODE_PAT_PARAM[]             = "code_pat";
 
 static const char MAIL_LINE_SEPARATOR[]             = "\r\n";
 
@@ -71,30 +72,28 @@ void get_upload_param(apr_pool_t *pool, apr_array_header_t *content_array,
                       const char **file_name, const char **file_mime,
                       apr_uint64_t *file_size, const char **file_digest,
                       const char **file_temp_path, const char **remove_pass,
-                      const char **download_pass, const char **comment)
+                      const char **download_pass, const char **comment,
+                      const char **code_pat)
 {
     typename RFC1867Parser<R>::content_t *file_content;
     typename RFC1867Parser<R>::content_t *comment_content;
     typename RFC1867Parser<R>::content_t *remove_pass_content;
     typename RFC1867Parser<R>::content_t *download_pass_content;
+    typename RFC1867Parser<R>::content_t *code_pat_content;
 
-    file_content = MultipartMessageParser<R>::get_content(content_array,
-                                                          POST_FILE_PARAM);
-    comment_content = MultipartMessageParser<R>::get_content(content_array,
-                                                    POST_COMMENT_PARAM);
-    remove_pass_content = MultipartMessageParser<R>::get_content(content_array,
-                                                        POST_REMOVE_PASS_PARAM);
-    download_pass_content = MultipartMessageParser<R>::get_content(content_array,
-                                                          POST_DOWNLOAD_PASS_PARAM);
+    file_content = MultipartMessageParser<R>::get_content
+        (content_array, POST_FILE_PARAM);
+    comment_content = MultipartMessageParser<R>::get_content
+        (content_array, POST_COMMENT_PARAM);
+    remove_pass_content = MultipartMessageParser<R>::get_content
+        (content_array, POST_REMOVE_PASS_PARAM);
+    download_pass_content = MultipartMessageParser<R>::get_content
+        (content_array, POST_DOWNLOAD_PASS_PARAM);
+    code_pat_content = MultipartMessageParser<R>::get_content
+        (content_array, POST_CODE_PAT_PARAM);
 
     if ((file_content == NULL) ||
-        (file_content->type != MultipartMessageParser<R>::FILE) ||
-        (comment_content == NULL) ||
-        (comment_content->type != MultipartMessageParser<R>::TEXT) ||
-        (remove_pass_content == NULL) ||
-        (remove_pass_content->type != MultipartMessageParser<R>::TEXT) ||
-        (download_pass_content == NULL) ||
-        (download_pass_content->type != MultipartMessageParser<R>::TEXT)) {
+        (file_content->type != MultipartMessageParser<R>::FILE)) {
         THROW(MESSAGE_POST_DATA_INVALID);
     }
 
@@ -103,9 +102,34 @@ void get_upload_param(apr_pool_t *pool, apr_array_header_t *content_array,
     *file_size      = file_content->file.size;
     *file_digest    = file_content->file.digest;
     *file_temp_path = file_content->file.temp_path;
-    *remove_pass    = remove_pass_content->text;
-    *download_pass  = download_pass_content->text;
-    *comment        = comment_content->text;
+
+    if ((comment_content == NULL) ||
+        (comment_content->type != MultipartMessageParser<R>::TEXT)) {
+        *comment = "";
+    } else {
+        *comment = comment_content->text;
+    }
+
+    if ((remove_pass_content == NULL) ||
+        (remove_pass_content->type != MultipartMessageParser<R>::TEXT)) {
+        *remove_pass = "";
+    } else {
+        *remove_pass = remove_pass_content->text;
+    }
+
+    if ((download_pass_content == NULL) ||
+        (download_pass_content->type != MultipartMessageParser<R>::TEXT)) {
+        *download_pass = "";
+    } else {
+        *download_pass = download_pass_content->text;
+    }
+
+    if ((code_pat_content == NULL) ||
+        (code_pat_content->type != MultipartMessageParser<R>::TEXT)) {
+        *code_pat = "";
+    } else {
+        *code_pat = code_pat_content->text;
+    }
 }
 
 template<class R>
