@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 2562 2007-08-18 08:56:57Z svn $
+ * $Id: Auxiliary.cpp 2575 2007-10-13 08:17:57Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -49,7 +49,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2562 2007-08-18 08:56:57Z svn $");
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 2575 2007-10-13 08:17:57Z svn $");
 
 void init_atomic(apr_pool_t *pool)
 {
@@ -341,7 +341,6 @@ const char *size_str(apr_pool_t *pool, apr_uint64_t size)
     static const long int CMP_FACTOR    = 1024;
     apr_size_t temp_size;
     const char *unit_str;
-    ldiv_t size_num;
 
     // MEMO: 約 400 TB 以上だと桁あふれして誤動するので注意
 
@@ -366,10 +365,10 @@ const char *size_str(apr_pool_t *pool, apr_uint64_t size)
         }
     } while (0);
 
-    size_num = std::ldiv(temp_size * 10 / CMP_FACTOR, 10L);
-
     return apr_psprintf(pool, "%ld.%ld %s",
-                        size_num.quot, size_num.rem, unit_str);
+                        temp_size / CMP_FACTOR,
+                        (temp_size * 10 / CMP_FACTOR) % 10,
+                        unit_str);
 }
 
 #ifndef HAVE_STRNCHR
@@ -548,7 +547,7 @@ void show_usage(const char *prog_name)
 
 void run_size_str(apr_pool_t *pool)
 {
-    static const apr_size_t TEST_COUNT  = 10000000;
+    static const apr_size_t TEST_COUNT  = 100000;
     apr_uint64_t num;
     const char *str;
     const char *str_ref;
@@ -561,11 +560,11 @@ void run_size_str(apr_pool_t *pool)
     for (apr_size_t i = 0; i < TEST_COUNT; i++) {
         num = rand();
         str = size_str(pool, num);
-//         str_ref = size_str_ref(pool, num);
+        str_ref = size_str_ref(pool, num);
 
-//         if (strcmp(str, str_ref)) {
-//             THROW(MESSAGE_BUG_FOUND);
-//         }
+        if (strcmp(str, str_ref)) {
+            THROW(MESSAGE_BUG_FOUND);
+        }
     }
     end_time = get_usage_sec();
 
