@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.cpp 2507 2007-07-06 19:08:20Z svn $
+ * $Id: DownloadFlowController.cpp 2576 2007-10-13 19:18:17Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,7 +35,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2507 2007-07-06 19:08:20Z svn $");
+SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2576 2007-10-13 19:18:17Z svn $");
 
 const apr_size_t DownloadSession::DOWNLOAD_BUSY_SLEEP_SEC   = 5;
 
@@ -195,19 +195,6 @@ const char *DownloadFlowController::dump_downloader(apr_pool_t *pool,
 }
 
 
-bool DownloadSession::is_valid()
-{
-    if (!is_valid_) {
-        is_valid_ = flow_controller_->add_session(sockaddr_);
-
-        if (!is_valid_) {
-            apr_sleep(apr_time_from_sec(DOWNLOAD_BUSY_SLEEP_SEC));
-        }
-    }
-    return is_valid_;
-}
-
-
 /******************************************************************************
  * テスト
  *****************************************************************************/
