@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.cpp 2388 2007-03-10 11:34:50Z svn $
+ * $Id: MmapFileWriter.cpp 2595 2007-10-22 14:36:13Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -39,7 +39,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: MmapFileWriter.cpp 2388 2007-03-10 11:34:50Z svn $");
+SOURCE_INFO_ADD("$Id: MmapFileWriter.cpp 2595 2007-10-22 14:36:13Z svn $");
 #endif
 
 #if defined(HAVE_GETPAGESIZE) && !defined(WIN32)
@@ -87,15 +87,18 @@ MmapFileWriter::~MmapFileWriter()
 /******************************************************************************
  * private メソッド
  *****************************************************************************/
-void MmapFileWriter::write_impl(const void *buffer, apr_size_t size)
+apr_size_t MmapFileWriter::write_impl(const void *buffer, apr_size_t size)
 {
     const char *data;
+    apr_size_t remain_size;
     apr_size_t write_size;
 
+    remain_size = size;
     data = AS_CONST_CHAR(buffer);
 
-    while (size > 0) {
-        write_size = (size > BLOCK_SIZE) ? BLOCK_SIZE : size;
+    while (remain_size > 0) {
+        write_size
+            = (remain_size > BLOCK_SIZE) ? BLOCK_SIZE : remain_size;
 
         if (write_size > (BLOCK_SIZE-block_offset_)) {
             if (block_offset_ != BLOCK_SIZE) {
@@ -103,7 +106,7 @@ void MmapFileWriter::write_impl(const void *buffer, apr_size_t size)
 
                 memcpy(AS_CHAR(file_map_->mm)+block_offset_, data, write_size);
                 data += write_size;
-                size -= write_size;
+                remain_size -= write_size;
             }
             expand();
 
@@ -114,8 +117,10 @@ void MmapFileWriter::write_impl(const void *buffer, apr_size_t size)
 
         data += write_size;
         block_offset_ += write_size;
-        size -= write_size;
+        remain_size -= write_size;
     }
+
+    return size;
 }
 
 void MmapFileWriter::expand()
@@ -129,6 +134,11 @@ void MmapFileWriter::expand()
     file_map_ = file_->mmap(pseudo_size - BLOCK_SIZE, BLOCK_SIZE,
                             APR_MMAP_READ|APR_MMAP_WRITE);
 
+#if defined(HAVE_MADVISE) && !defined(WIN32)
+    // シーケンシャルアクセスしかしない
+    madvise(file_map_->mm, file_map_->size, MADV_SEQUENTIAL);
+#endif
+
     block_offset_ = 0;
 }
 
