@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostDataChecker.cpp 2437 2007-06-25 14:35:18Z svn $
+ * $Id: PostDataChecker.cpp 2604 2007-10-26 13:58:10Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -36,7 +36,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostDataChecker.cpp 2437 2007-06-25 14:35:18Z svn $");
+SOURCE_INFO_ADD("$Id: PostDataChecker.cpp 2604 2007-10-26 13:58:10Z svn $");
 
 const char PostDataChecker::HTML_EXT[]      = "htm";
 
@@ -49,13 +49,14 @@ void PostDataChecker::validate_uitem(apr_pool_t *pool, apr_uint64_t file_size,
                                      const char *file_digest,
                                      const char *remove_pass,
                                      const char *download_pass,
-                                     const char **comment)
+                                     const char **comment,
+                                     const char *code_pat)
 {
     const char *file_ext;
 
-    validate_file_name(pool, file_name);
+    validate_file_name(pool, file_name, code_pat);
     validate_file_mime(pool, *file_mime);
-    validate_comment(pool, comment);
+    validate_comment(pool, comment, code_pat);
     file_ext = get_file_ext(*file_name);
     validate_file_ext(file_ext);
 
@@ -103,17 +104,19 @@ void PostDataChecker::validate_uitem(apr_pool_t *pool, apr_uint64_t file_size,
  * private メソッド
  *****************************************************************************/
 void PostDataChecker::validate_file_name(apr_pool_t *pool,
-                                         const char **file_name)
+                                         const char **file_name,
+                                         const char *code_pat)
 {
     if (strlen(*file_name) == 0) {
         return;
     }
 
     // 不正なシーケンスを排除
-    *file_name = CharCodeConverter::convert(pool, *file_name,
-                                            SYS_CHARACTER_CODE,
-                                            SYS_CHARACTER_CODE);
+    *file_name = CharCodeConverter::convert
+        (pool, *file_name,
+         reinterpret_cast<const unsigned char *>(code_pat));
 
+    // 良い方法じゃないけど...
     for (const char *name = *file_name; *name != '\0'; name++) {
         if ((*name == '<') || (*name == '>') || (*name == '"') ||
             (*name == '\'') || (*name == '\r') || (*name == '\n') ||
@@ -128,7 +131,8 @@ void PostDataChecker::validate_file_mime(apr_pool_t *pool,
 {
     for (const char *mime = file_mime; *mime != '\0'; mime++) {
         if (isalnum(*mime) || (*mime == '-') || (*mime == '+') ||
-            (*mime == '.') || (*mime == '/')) {
+            (*mime == '.') || (*mime == '/') || (*mime == ';') ||
+            (*mime == '=') || (*mime == ' ')) {
             continue;
         }
 
@@ -136,7 +140,8 @@ void PostDataChecker::validate_file_mime(apr_pool_t *pool,
     }
 }
 
-void PostDataChecker::validate_comment(apr_pool_t *pool, const char **comment)
+void PostDataChecker::validate_comment(apr_pool_t *pool, const char **comment,
+                                       const char *code_pat)
 {
     apr_size_t escaped_length;
 
@@ -145,9 +150,9 @@ void PostDataChecker::validate_comment(apr_pool_t *pool, const char **comment)
     }
 
     // 不正なシーケンスを排除
-    *comment = CharCodeConverter::convert(pool, *comment,
-                                          SYS_CHARACTER_CODE,
-                                          SYS_CHARACTER_CODE);
+    *comment = CharCodeConverter::convert
+        (pool, *comment,
+         reinterpret_cast<const unsigned char *>(code_pat));
 
     escape_html(pool, *comment, strlen(*comment), comment, &escaped_length);
 }
