@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RFC1867Parser.cpp 2388 2007-03-10 11:34:50Z svn $
+ * $Id: RFC1867Parser.cpp 2595 2007-10-22 14:36:13Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -41,11 +41,9 @@
 using namespace std;
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: RFC1867Parser.cpp 2388 2007-03-10 11:34:50Z svn $");
+SOURCE_INFO_ADD("$Id: RFC1867Parser.cpp 2595 2007-10-22 14:36:13Z svn $");
 #endif
 
-#define AS_CONTENT(pointer)         reinterpret_cast<content_t *>(pointer)
-
 #ifdef DEBUG_RFC1867Parser
 #define DUMP_INPUT_AND_THROW(message) M::dump_input(M::buffer_); THROW(message)
 #else
@@ -90,7 +88,7 @@ RFC1867Parser<R, W>::RFC1867Parser(apr_pool_t *pool, PostReaderClass& reader,
 
 template<class R, class W>
 apr_array_header_t *RFC1867Parser<R, W>::parse(const char *content_type,
-                                               apr_size_t content_size)
+                                               apr_uint64_t content_size)
 {
     apr_array_header_t *content_array;
     content_t content;
@@ -174,7 +172,7 @@ void RFC1867Parser<R, W>::get_content(content_t *content)
                       &(content->file.name));
 
     if (start == NULL) { // テキスト
-        start = M::skip_line(line_end);
+        start = M::skip_header(line_end - LITERAL_STRLEN(M::CR_LF));
         M::buffer_.erase(start - M::buffer_.get_data());
 
         M::get_text_content(content);
@@ -185,12 +183,12 @@ void RFC1867Parser<R, W>::get_content(content_t *content)
         line_end = M::skip_line(start);
 
         start = M::skip(start, M::CONTENT_TYPE);
-        content->file.mime = AS_CONST_CHAR(apr_pstrmemdup(M::pool_,
-                                                          start,
-                                                          line_end - start -
-                                                          strlen(M::CR_LF)));
+        content->file.mime
+            = AS_CONST_CHAR(apr_pstrmemdup(M::pool_, start,
+                                           line_end - start -
+                                           LITERAL_STRLEN(M::CR_LF)));
 
-        start = M::skip_line(line_end);
+        start = M::skip_header(line_end - LITERAL_STRLEN(M::CR_LF));
         M::buffer_.erase(start - M::buffer_.get_data());
 
         M::get_file_content(content);
