@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 2560 2007-08-13 16:29:46Z svn $
+ * $Id: TemplateExecutor.cpp 2569 2007-10-12 16:23:04Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -41,7 +41,7 @@
 using namespace std;
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2560 2007-08-13 16:29:46Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateExecutor.cpp 2569 2007-10-12 16:23:04Z svn $");
 #endif
 
 #ifdef DEBUG_TemplateExecutor
@@ -743,6 +743,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     apr_shm_t *item_list_shm;
     apr_shm_t *thumbnail_list_shm;
     UploadItemList *item_list;
+    apr_time_t mtime;
     ThumbnailList *thumbnail_list;
 
     if (argc < 3) {
@@ -772,8 +773,9 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     thumbnail_list = ThumbnailList::get_instance(thumbnail_list_shm,
                                                  MAX_LIST_SIZE);
     item_list = UploadItemListReader::read(pool, data_dir_path, data_dir_path,
+                                           MAX_FILE_SIZE, MAX_LIST_SIZE,
                                            item_list_shm, thumbnail_list,
-                                           MAX_FILE_SIZE, MAX_LIST_SIZE);
+                                           &mtime);
 
     show_item("data dir", data_dir_path);
     show_item("template file", tmpl_file_path);
