@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 2563 2007-08-28 04:12:55Z svn $
+ * $Id: UploadItem.cpp 2604 2007-10-26 13:58:10Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItem.cpp 2563 2007-08-28 04:12:55Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItem.cpp 2604 2007-10-26 13:58:10Z svn $");
 
 #define AS_BCOMMENT(pointer)        reinterpret_cast<bbs_comment_t *>(pointer)
 #define UINT16(pointer)             static_cast<apr_uint16_t>(pointer)
@@ -64,6 +64,7 @@ UploadItem *UploadItem::get_instance(void *memory, apr_size_t item_id,
                                      const char *remove_pass,
                                      const char *download_pass,
                                      const char *comment,
+                                     const char *code_pat,
                                      bool is_need_validate)
 {
     UploadItem *uitem;
@@ -74,7 +75,8 @@ UploadItem *UploadItem::get_instance(void *memory, apr_size_t item_id,
     if (is_need_validate) {
         PostDataChecker::validate_uitem(temp_pool.get(), file_size, mtime,
                                         &file_name, &file_mime, file_digest,
-                                        remove_pass, download_pass, &comment);
+                                        remove_pass, download_pass, &comment,
+                                        code_pat);
     }
 
     memset(memory, 0, sizeof(UploadItem));
@@ -111,6 +113,7 @@ UploadItem *UploadItem::get_instance(apr_pool_t *pool, apr_size_t item_id,
                                      const char *remove_pass,
                                      const char *download_pass,
                                      const char *comment,
+                                     const char *code_pat,
                                      bool is_need_validate)
 {
     void *memory;
@@ -119,7 +122,8 @@ UploadItem *UploadItem::get_instance(apr_pool_t *pool, apr_size_t item_id,
 
     return get_instance(memory, item_id, item_index, file_size, mtime,
                         ip_address, file_name, file_mime, file_digest,
-                        remove_pass, download_pass, comment, is_need_validate);
+                        remove_pass, download_pass, comment, code_pat,
+                        is_need_validate);
 }
 
 int UploadItem::cmp_download_count(const UploadItem *a, const UploadItem *b)
