@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 2567 2007-10-10 17:12:24Z svn $
+ * $Id: UploadItemList.cpp 2567M 2007-10-28 13:50:06Z (ローカル) $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -40,7 +40,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2567 2007-10-10 17:12:24Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemList.cpp 2567M 2007-10-28 13:50:06Z (ローカル) $");
 
 #define AS_UHEADER(pointer)     reinterpret_cast<UploadItem::header_t *>(pointer)
 #define AS_UITEM_LIST(pointer)  reinterpret_cast<UploadItemList *>(pointer)
@@ -236,7 +236,7 @@ UploadItem *create_uitem(apr_pool_t *pool, apr_uint64_t file_size)
 {
     return UploadItem::get_instance
         (pool, 0, 0, file_size, 0, "", "", "", "", "", "",
-         MESSAGE_TEST_COMMENT, false);
+         MESSAGE_TEST_COMMENT, "", false);
 }
 
 void run_full(apr_pool_t *pool, UploadItemList *item_list)
