@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemVariableCreator.cpp 2433 2007-05-20 12:47:02Z svn $
+ * $Id: UploadItemVariableCreator.cpp 2569 2007-10-12 16:23:04Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -32,7 +32,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemVariableCreator.cpp 2433 2007-05-20 12:47:02Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemVariableCreator.cpp 2569 2007-10-12 16:23:04Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -247,6 +247,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     apr_shm_t *item_list_shm;
     apr_shm_t *thumbnail_list_shm;
     UploadItemList *item_list;
+    apr_time_t mtime;
     ThumbnailList *thumbnail_list;
 
     if (argc != 3) {
@@ -271,8 +272,8 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     thumbnail_list = ThumbnailList::get_instance
         (thumbnail_list_shm, MAX_LIST_SIZE);
     item_list = UploadItemListReader::read
-        (pool, data_dir_path, data_dir_path, item_list_shm, thumbnail_list,
-         MAX_FILE_SIZE, MAX_LIST_SIZE);
+        (pool, data_dir_path, data_dir_path, MAX_FILE_SIZE, MAX_LIST_SIZE,
+         item_list_shm, thumbnail_list, &mtime);
 
     show_item("data dir", data_dir_path);
     show_item("template file", tmpl_file_path);
