@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: cgi_uploader.cpp 2561 2007-08-13 18:56:01Z svn $
+ * $Id: cgi_uploader.cpp 2568 2007-10-11 15:47:19Z svn $
  *****************************************************************************/
 
 /**
@@ -49,12 +49,10 @@
 #define TEMPLATE_INSTANTIATION
 #include "uploader_handler.cpp"
 
-SOURCE_INFO_ADD("$Id: cgi_uploader.cpp 2561 2007-08-13 18:56:01Z svn $");
-
-#define BENCHMARK 50000
+SOURCE_INFO_ADD("$Id: cgi_uploader.cpp 2568 2007-10-11 15:47:19Z svn $");
 
 // strace したときに，表示処理の範囲を見分けるための印
-#ifdef __linux__
+#if defined(DEBUG) && defined(__linux__)
 #define STRACE_MARKER() sched_yield()
 #else
 #define STRACE_MARKER()
@@ -66,11 +64,13 @@ int main(int argc, const char * const *argv)
     const char *arg;
     UploaderConfig *config;
     int status;
+    apr_size_t bench_count;
 
     apr_app_initialize(&argc, &argv, NULL);
     apr_pool_create(&pool, NULL);
 
     config = NULL;
+    status = 0;
     try {
         arg = getenv("PATH_INFO");
         if (arg == NULL) {
@@ -89,11 +89,14 @@ int main(int argc, const char * const *argv)
         config = UploaderConfigReader::read(pool, CONF_FILE_NAME);
         config->child_init();
 
+        // ベンチマーク用
+        bench_count = atoi(getenv("UPLOADER_BENCH"));
+        if (bench_count == 0) {
+            bench_count++;
+        }
+
         STRACE_MARKER();
-#ifdef BENCHMARK
-        for (apr_size_t i = 0; i < BENCHMARK; i++)
-#endif
-        {
+        for (apr_size_t i = 0; i < bench_count; i++) {
             TemporaryPool temp_pool(pool);
             CGIResponse::Handle handle(temp_pool.get());
 
