@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2542 2007-08-02 16:14:34Z svn $
+ * $Id: uploader_handler.cpp 2613 2007-10-28 02:47:22Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -57,7 +57,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2542 2007-08-02 16:14:34Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2613 2007-10-28 02:47:22Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command)                        \
@@ -79,6 +79,7 @@ static const char CURRENT_PAGE_VAR_NAME[]       = "CURRENT_PAGE";
 static const char ERROR_MESSAGE_VAR_NAME[]      = "ERROR_MESSAGE";
 
 static const char INDEX_COMMAND[]               = "index";
+static const char INFO_COMMAND[]                = "info";
 static const char THUMBNAIL_COMMAND[]           = "thumbnail";
 static const char THUMBNAIL_VIEW_COMMAND[]      = "view";
 static const char MAIL_COMMAND[]                = "mail";
@@ -88,7 +89,9 @@ static const char RSS_COMMAND[]                 = "rss";
 static const char UPLOAD_COMMAND[]              = "upload";
 static const char PROGRESS_DATA_COMMAND[]       = "progress_data";
 static const char ADMIN_COMMAND[]               = "admin";
-static const char INFO_COMMAND[]                = "info";
+static const char ADMIN_INFO_COMMAND[]          = "info";
+
+static const char UPLOAD_ID_ARG[]               = "upload_id";
 
 static const char PAGE_CONTENT_TYPE[]           = "text/html; charset=EUC-JP";
 
@@ -270,6 +273,88 @@ static int index(typename Response::Handle *r, UploaderConfig *config,
     return OK;
 }
 
+template<class Response>
+static int info(typename Response::Handle *r, UploaderConfig *config,
+                apr_size_t item_id)
+{
+    Response::set_content_type(r, PAGE_CONTENT_TYPE);
+    Response::header_end(r);
+
+    if (Response::is_head_method(r)) {
+        return OK;
+    }
+
+    typename Response::Writer o(r);
+    try {
+        UploaderTemplate *tmpl;
+        UploadItem *uitem;
+
+        uitem = config->get_item_manager()->get_item(r->pool, item_id);
+
+        tmpl = config->get_template(UploaderConfig::INFO_VIEW);
+
+        TemplateVariableCreator var_creator(r->pool, tmpl->get_ids());
+
+        var_creator.create(BASE_URL_VAR_NAME, config->base_url);
+
+        var_creator.create
+            (ITEM_VAR_NAME,
+             tmpl->get_item_var_creator()->create(r->pool, uitem));
+
+        TemplateExecutor<typename Response::Writer> executor(r->pool, o);
+
+        executor.exec(tmpl->get_node_tree(), var_creator.get_variables(),
+                      tmpl->get_key_count());
+    } catch(const char *message) {
+        return error_with_log<Response>(r, o, config, message);
+    }
+    o.finish();
+
+    return OK;
+}
+
+template<class Response>
+static int info(typename Response::Handle *r, UploaderConfig *config,
+                const char *arg)
+{
+    apr_size_t item_id;
+    const char *first_arg;
+
+    first_arg = get_word(r->pool, &arg, ARG_SEPARATE_STR[0]);
+
+    if (strlen(first_arg) == 0) {
+        return HTTP_BAD_REQUEST;
+    }
+
+    if (strncmp(first_arg, UPLOAD_ID_ARG, LITERAL_STRLEN(UPLOAD_ID_ARG)) == 0) {
+        apr_uint32_t upload_id;
+        RequestReader::post_progress_t *progress;
+
+        upload_id = static_cast<apr_size_t>
+            (apr_atoi64(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])));
+        progress = config->get_post_progress_list()->get(upload_id);
+
+        if (UNLIKELY(progress->id != upload_id)) {
+            typename Response::Writer o(r);
+
+            return redirect<Response>
+                (r, o,
+                 apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR,
+                             NULL));
+        }
+
+        item_id = progress->item_id;
+    } else {
+        const char *item_id_str;
+
+        item_id_str = apr_pstrdup(r->pool, first_arg);
+        item_id = static_cast<apr_size_t>
+            (apr_atoi64(get_word(r->pool, &item_id_str, FILE_EXT_SEPARATOR[0])));
+    }
+
+    return info<Response>(r, config, item_id);
+}
+
 template<class Response>
 static int thumbnail_view(typename Response::Handle *r, UploaderConfig *config,
                           const char *arg)
@@ -410,25 +495,28 @@ static int upload_impl(typename Response::Handle *r, UploaderConfig *config,
                        const char *file_name, const char *file_mime,
                        apr_uint64_t file_size, const char *file_digest,
                        const char *file_temp_path, const char *remove_pass,
-                       const char *download_pass, const char *comment)
+                       const char *download_pass, const char *comment,
+                       const char *code_pat, apr_size_t *item_id)
 {
-    apr_size_t item_id;
-
-    typename Response::Writer o(r);
-
-    item_id = config->get_item_manager()->add
+    *item_id = config->get_item_manager()->add
         (r->pool, file_name, file_mime, file_size, file_digest,
          file_temp_path, remove_pass, download_pass, comment,
-         Response::get_remote_ip(r));
+         code_pat, Response::get_remote_ip(r));
 
     regist_post(config, Response::get_remote_addr(r));
 
     Response::set_env(r, "uploader_upload", "");
     Response::set_env(r, "uploader_item_id",
-                      apr_psprintf(r->pool, "%u", item_id));
+                      apr_psprintf(r->pool, "%u", *item_id));
+
+    typename Response::Writer o(r);
 
     return redirect<Response>
-        (r, o, apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR, NULL));
+        (r, o,
+         apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR,
+                     INFO_COMMAND, ARG_SEPARATE_STR,
+                     apr_psprintf(r->pool, "%u", *item_id),
+                     NULL));
 }
 
 template<class Response>
@@ -447,6 +535,7 @@ static int upload(typename Response::Handle *r, UploaderConfig *config,
     const char *remove_pass;
     const char *download_pass;
     const char *comment;
+    const char *code_pat;
 
     int status;
 
@@ -485,16 +574,19 @@ static int upload(typename Response::Handle *r, UploaderConfig *config,
 
     file_temp_path = NULL;
     try {
+        apr_size_t item_id;
+
         get_upload_param<typename Response::Reader>
             (r->pool, content_array,
              &file_name, &file_mime, &file_size, &file_digest, &file_temp_path,
-             &remove_pass, &download_pass, &comment);
+             &remove_pass, &download_pass, &comment, &code_pat);
 
         status = upload_impl<Response>
             (r, config,
              file_name, file_mime, file_size, file_digest, file_temp_path,
-             remove_pass, download_pass, comment);
+             remove_pass, download_pass, comment, code_pat, &item_id);
 
+        progress->item_id = item_id;
         progress->is_succeeded  = true;
 
         return status;
@@ -586,6 +678,8 @@ static int mail_upload(typename Response::Handle *r, UploaderConfig *config,
 
     file_temp_path = NULL;
     try {
+        apr_size_t item_id;
+
         get_mail_upload_param<typename Response::Reader>
             (r->pool, content_array,
              &file_name, &file_mime, &file_size, &file_digest, &file_temp_path,
@@ -594,7 +688,7 @@ static int mail_upload(typename Response::Handle *r, UploaderConfig *config,
         return upload_impl<Response>
             (r, config,
              file_name, file_mime, file_size, file_digest, file_temp_path,
-             remove_pass, download_pass, comment);
+             remove_pass, download_pass, comment, "", &item_id);
     } catch(const char *message) {
         if (file_temp_path != NULL) {
             apr_file_remove(file_temp_path, r->pool);
@@ -891,7 +985,7 @@ static int rss(typename Response::Handle *r, UploaderConfig *config,
 }
 
 template<class Response>
-static int info(typename Response::Handle *r, UploaderConfig *config)
+static int admin_info(typename Response::Handle *r, UploaderConfig *config)
 {
     Response::set_content_type(r, "text/plain");
     Response::header_end(r);
@@ -932,8 +1026,8 @@ static int admin(typename Response::Handle *r, UploaderConfig *config,
         return download<Response>(r, config, admin_arg, true);
     } else if (strcmp(admin_command, REMOVE_COMMAND) == 0) {
         return remove<Response>(r, config, admin_arg, true);
-    } else if (IS_REQUEST_COMMAND(admin_command, INFO_COMMAND)) {
-        return info<Response>(r, config);
+    } else if (IS_REQUEST_COMMAND(admin_command, ADMIN_INFO_COMMAND)) {
+        return admin_info<Response>(r, config);
     }
 
     page_count = (config->get_item_list()->size() == 0)
@@ -1018,6 +1112,8 @@ int uploader_command_handler(typename Response::Handle *r, UploaderConfig *confi
 
     if ((*command == '\0') || IS_REQUEST_COMMAND(command, INDEX_COMMAND)) {
         return index<Response>(r, config, arg);
+    } else if (IS_REQUEST_COMMAND(command, INFO_COMMAND)) {
+        return info<Response>(r, config, arg);
     } else if (IS_REQUEST_COMMAND(command, THUMBNAIL_COMMAND)) {
         return thumbnail<Response>(r, config, arg);
     } else if (IS_REQUEST_COMMAND(command, UPLOAD_COMMAND)) {
