@@ -21,13 +21,14 @@ use constant TEST_COMMENT   => 'test';
 use constant TEST_DL_PASS   => 'D';
 use constant TEST_RM_PASS   => 'R';
 
-use constant VIEW_WORKER    => 5;
-use constant SMALL_COUNT    => 20;
-use constant LARGE_COUNT    => 20;
+use constant VIEW_WORKER    => 10;
+use constant SMALL_COUNT    => 40;
+use constant LARGE_COUNT    => 10;
 
 plan tests => SMALL_COUNT*2 + LARGE_COUNT*2;
 
 my $stop_view : shared = 0;
+my @threads;
 
 sub upload {
     my $file = shift;
@@ -74,13 +75,11 @@ foreach (1..VIEW_WORKER) {
 
 # upload
 foreach my $conf (@conf) {
-    my @threads;
-
     foreach (1..$conf->{count}) {
         push(@threads, threads->new(\&upload, $conf->{file}));
     }
 
-    foreach my $thread (@threads) {
+    while (my $thread = pop(@threads)) {
         ok($thread->join() == 0, "upload finish");
     }
 }
