@@ -32,7 +32,27 @@ namespace UploaderConfig
 
         private static string getApacheDir()
         {
-            string keyName = "Software\\Apache Software Foundation\\Apache";
+            string apacheDir;
+
+            if ((apacheDir = getApache22Dir()) != "") {
+                return apacheDir;
+            } else {
+                return getApache20Dir();
+            }
+        }
+
+        private static string getApache22Dir()
+        {
+            return getApacheDirImpl("Software\\Apache Software Foundation\\Apache");
+        }
+
+        private static string getApache20Dir()
+        {
+            return getApacheDirImpl("Software\\Apache Group\\Apache");
+        }
+
+        private static string getApacheDirImpl(string keyName)
+        {
             string valueName = "ServerRoot";
 
             string dir = "";
@@ -354,7 +374,7 @@ namespace UploaderConfig
             dialog.Title = label.Text + "IĂ";
             dialog.CheckFileExists = true;
             dialog.FileName = currentFile;
-            dialog.Filter = "W[(mod_fast_bbs.so)|mod_fast_bbs.so";
+            dialog.Filter = "W[(mod_uploader.so)|mod_uploader*.so";
             dialog.FilterIndex = 0;
 
             if (dialog.ShowDialog() != DialogResult.OK) {
@@ -412,7 +432,8 @@ namespace UploaderConfig
         {
             string path = (sender as TextBox).Text;
 
-            if (!File.Exists(Path.Combine(Path.Combine(path, "bin"), "httpd.exe"))) {
+            if ((!File.Exists(Path.Combine(Path.Combine(path, "bin"), "httpd.exe"))) &&
+                (!File.Exists(Path.Combine(Path.Combine(path, "bin"), "Apache.exe")))) {
                 errorProvider.SetError(sender as TextBox,
                     "u" + apachePathLabel.Text + "v܂");
                 return;
